@@ -79,8 +79,10 @@ expandTaxonTree<-function(taxonTree,taxaData,collapse=NULL,keepBrLen=FALSE,plot=
 	#taxonTree<-rtree(10);taxonTree$tip.label<-as.character(1:10);collapse<-sample(taxonTree$tip.label,5)
 	#taxaData<-as.character(sample(1:10,100,replace=TRUE));names(taxaData)<-paste("t",1:100,sep="")
 	#require(ape)
-	if(!is(taxonTree, "phylo")){stop("Error: taxonTree is not of class phylo")}
-	if(any(is.na(taxaData))){stop("Error: some values of taxonData missing!!")}
+	if(!inherits(taxonTree, "phylo")){
+		stop("taxonTree is not of class phylo")
+		}
+	if(any(is.na(taxaData))){stop("some values of taxonData missing!!")}
 	if(!is.null(collapse) & keepBrLen){
 		message("Warning: collapsed branch lengths turned to zero when keepBrLen is TRUE!")}
 	tree<-taxonTree
@@ -93,8 +95,11 @@ expandTaxonTree<-function(taxonTree,taxaData,collapse=NULL,keepBrLen=FALSE,plot=
 			}}
 		cotaxa<-names(taxaData)[taxaData==i]	#which species do I want? These...
 		repTree<-stree(length(cotaxa))		#replacement polytomy
-		if(keepBrLen){repTree$edge.length<-rep(0,length(cotaxa))
-			}else{repTree$edge.length<-rep(1,length(cotaxa))}
+		if(keepBrLen){
+			repTree$edge.length<-rep(0,length(cotaxa))
+		}else{
+			repTree$edge.length<-rep(1,length(cotaxa))
+			}
 		repTree$tip.label<-cotaxa			#replace names,edge.lengths
 		tree<-bind.tree(tree,repTree,tip)	#replace the right tip	
 		}
@@ -102,10 +107,13 @@ expandTaxonTree<-function(taxonTree,taxaData,collapse=NULL,keepBrLen=FALSE,plot=
 	if(!keepBrLen){
 		tree1<-di2multi(tree)
 		tree1$edge.length<-NULL
-		tree1<-collapse.singles(tree1)
-		if(!testEdgeMat(tree1)){stop("Edge matrix has inconsistencies")}
-		tree1<-read.tree(text=write.tree(tree1))
-		}else{tree1<-tree}
+		#tree1<-collapse.singles(tree1)
+		#if(!testEdgeMat(tree1)){stop("Edge matrix has inconsistencies")}
+		#tree1<-read.tree(text=write.tree(tree1))
+		tree1<-cleanNewPhylo(tree1)
+	}else{
+		tree1<-tree
+		}
 	if(plot==TRUE){layout(1:2);plot(taxonTree);plot(tree1);layout(1)}
 	return(tree1)
 	}
